@@ -28,8 +28,7 @@ Q_SIGNALS:
     void noSettingsImported(const QString &name);
 
 protected:
-    Q_DISABLE_COPY(AbstractImapSettingsCheckJob)
-    void checkNoSettingsImported();
+    LIBSIEVEEDITOR_NO_EXPORT void checkNoSettingsImported();
     AbstractImapSettingsPassword *mPasswordImporter = nullptr;
     bool mSettingsWereImported = false;
 };
